@@ -1,7 +1,8 @@
-from hestia_earth.schema import EmissionMethodTier
+from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition
 
 from hestia_earth.models.log import logger
 from hestia_earth.models.utils.emission import _new_emission
+from hestia_earth.models.utils.cycle import valid_site_type
 from . import MODEL
 from .utils import _get_aboveGroundCropResidueBurnt_value
 
@@ -14,6 +15,7 @@ def _emission(value: float):
     emission = _new_emission(TERM_ID, MODEL)
     emission['value'] = [value]
     emission['methodTier'] = EmissionMethodTier.TIER_1.value
+    emission['statsDefinition'] = EmissionStatsDefinition.MODELLED.value
     return emission
 
 
@@ -24,7 +26,7 @@ def _run(product_value: list):
 
 def _should_run(cycle: dict):
     aboveGroundCropResidueBurnt_value = _get_aboveGroundCropResidueBurnt_value(cycle)
-    should_run = len(aboveGroundCropResidueBurnt_value) > 0
+    should_run = valid_site_type(cycle) and len(aboveGroundCropResidueBurnt_value) > 0
     logger.info('model=%s, term=%s, should_run=%s', MODEL, TERM_ID, should_run)
     return should_run, aboveGroundCropResidueBurnt_value
 
