@@ -1,3 +1,4 @@
+from hestia_earth.schema import IndicatorStatsDefinition
 from hestia_earth.utils.tools import list_sum
 
 from hestia_earth.models.log import logger
@@ -10,6 +11,7 @@ def _indicator(term: str, value: float):
     logger.info('term=%s, value=%s', term.get('@id'), value)
     indicator = _new_indicator(term)
     indicator['value'] = value
+    indicator['statsDefinition'] = IndicatorStatsDefinition.MODELLED.value
     return indicator
 
 
