@@ -1,11 +1,12 @@
-from hestia_earth.schema import EmissionMethodTier
+from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition
 
 from hestia_earth.models.log import logger
 from hestia_earth.models.utils.constant import Units, get_atomic_conversion
-from hestia_earth.models.utils.input import get_animal_product_N_total
+from hestia_earth.models.utils.cycle import get_excreta_N_total
 from hestia_earth.models.utils.emission import _new_emission
+from hestia_earth.models.utils.cycle import valid_site_type
 from . import MODEL
-from .utils import get_N_N2O_excreate_coeff_from_primary_product
+from .utils import get_N_N2O_excreta_coeff_from_primary_product
 
 TERM_ID = 'n2OToAirExcretaDirect'
 
@@ -15,18 +16,19 @@ def _emission(value: float):
     emission = _new_emission(TERM_ID, MODEL)
     emission['value'] = [value]
     emission['methodTier'] = EmissionMethodTier.TIER_1.value
+    emission['statsDefinition'] = EmissionStatsDefinition.MODELLED.value
     return emission
 
 
 def _run(cycle: dict, N_total: float):
-    coefficient = get_N_N2O_excreate_coeff_from_primary_product(cycle)
+    coefficient = get_N_N2O_excreta_coeff_from_primary_product(cycle)
     value = N_total * coefficient * get_atomic_conversion(Units.KG_N2O, Units.TO_N)
     return [_emission(value)]
 
 
 def _should_run(cycle: dict):
-    N_total = get_animal_product_N_total(cycle)
-    should_run = N_total > 0
+    N_total = get_excreta_N_total(cycle)
+    should_run = valid_site_type(cycle, True) and N_total > 0
     logger.info('model=%s, term=%s, should_run=%s', MODEL, TERM_ID, should_run)
     return should_run, N_total
 
