@@ -1,10 +1,11 @@
-from hestia_earth.schema import EmissionMethodTier
+from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition
 
 from hestia_earth.models.log import logger
 from hestia_earth.models.utils.constant import Units, get_atomic_conversion
 from hestia_earth.models.utils.input import get_inorganic_fertilizer_N_total
 from hestia_earth.models.utils.crop import get_N2ON_fertilizer_coeff_from_primary_product
 from hestia_earth.models.utils.emission import _new_emission
+from hestia_earth.models.utils.cycle import valid_site_type
 from . import MODEL
 
 TERM_ID = 'n2OToAirInorganicFertilizerDirect'
@@ -15,6 +16,7 @@ def _emission(value: float):
     emission = _new_emission(TERM_ID, MODEL)
     emission['value'] = [value]
     emission['methodTier'] = EmissionMethodTier.TIER_1.value
+    emission['statsDefinition'] = EmissionStatsDefinition.MODELLED.value
     return emission
 
 
@@ -26,7 +28,7 @@ def _run(cycle: dict, N_total: float):
 
 def _should_run(cycle: dict):
     N_total = get_inorganic_fertilizer_N_total(cycle)
-    should_run = N_total > 0
+    should_run = valid_site_type(cycle, True) and N_total > 0
     logger.info('model=%s, term=%s, should_run=%s', MODEL, TERM_ID, should_run)
     return should_run, N_total
 
