@@ -1,7 +1,7 @@
-from hestia_earth.schema import EmissionMethodTier
+from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition
 
 from hestia_earth.models.log import logger
-from hestia_earth.models.utils.product import get_animal_product_N_total
+from hestia_earth.models.utils.cycle import get_excreta_N_total
 from hestia_earth.models.utils.emission import _new_emission
 from . import MODEL
 from .no3ToGroundwaterAllOrigins import _should_run, _get_value
@@ -14,13 +14,14 @@ def _emission(value: float):
     emission = _new_emission(TERM_ID, MODEL)
     emission['value'] = [value]
     emission['methodTier'] = EmissionMethodTier.TIER_2.value
+    emission['statsDefinition'] = EmissionStatsDefinition.MODELLED.value
     return emission
 
 
 def _run(cycle: dict, content_list_of_items: list):
-    noxToAirAllOrigins = _get_value(content_list_of_items)
-    value = get_animal_product_N_total(cycle)
-    return [_emission(value * noxToAirAllOrigins)]
+    no3ToGroundwaterAllOrigins = _get_value(content_list_of_items)
+    excreta_N_total = get_excreta_N_total(cycle)
+    return [_emission(excreta_N_total * no3ToGroundwaterAllOrigins)]
 
 
 def run(cycle: dict):
