@@ -1,4 +1,4 @@
-from hestia_earth.schema import EmissionMethodTier
+from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition
 
 from hestia_earth.models.log import logger
 from hestia_earth.models.utils.input import get_organic_fertilizer_N_total
@@ -14,13 +14,14 @@ def _emission(value: float):
     emission = _new_emission(TERM_ID, MODEL)
     emission['value'] = [value]
     emission['methodTier'] = EmissionMethodTier.TIER_2.value
+    emission['statsDefinition'] = EmissionStatsDefinition.MODELLED.value
     return emission
 
 
 def _run(cycle: dict, content_list_of_items: list):
-    noxToAirAllOrigins = _get_value(content_list_of_items)
+    no3ToGroundwaterAllOrigins = _get_value(content_list_of_items)
     value = get_organic_fertilizer_N_total(cycle)
-    return [_emission(value * noxToAirAllOrigins)]
+    return [_emission(value * no3ToGroundwaterAllOrigins)]
 
 
 def run(cycle: dict):
