@@ -1,8 +1,8 @@
-from hestia_earth.schema import EmissionMethodTier
+from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition
 
 from hestia_earth.models.log import logger
+from hestia_earth.models.utils.cycle import get_excreta_N_total
 from hestia_earth.models.utils.emission import _new_emission
-from hestia_earth.models.utils.input import get_animal_product_N_total
 from .n2OToAirAllOrigins import _get_value, _should_run
 from . import MODEL
 
@@ -14,13 +14,14 @@ def _emission(value: float):
     emission = _new_emission(TERM_ID, MODEL)
     emission['value'] = [value]
     emission['methodTier'] = EmissionMethodTier.TIER_2.value
+    emission['statsDefinition'] = EmissionStatsDefinition.MODELLED.value
     return emission
 
 
 def _run(cycle: dict, content_list_of_items: list, N_total: float):
     n2OToAirAllOrigins = _get_value(content_list_of_items, N_total)
-    value = get_animal_product_N_total(cycle)
-    return [_emission(value * n2OToAirAllOrigins / N_total)]
+    excreta_N_totallue = get_excreta_N_total(cycle)
+    return [_emission(excreta_N_totallue * n2OToAirAllOrigins / N_total)]
 
 
 def run(cycle: dict):
