@@ -8,15 +8,18 @@ class_path = f"hestia_earth.models.ipcc2006.{TERM_ID}"
 fixtures_folder = f"{fixtures_path}/ipcc2006/{TERM_ID}"
 
 
-@patch(f"{class_path}._most_relevant_measurement_value", return_value=[])
-def test_should_run(mock_measurement):
+@patch(F"{class_path}.find_primary_product", return_value={})
+@patch(f"{class_path}.valid_site_type", return_value=True)
+@patch(f"{class_path}.calculate_land_occupation", return_value=10)
+@patch(f"{class_path}.most_relevant_measurement_value", return_value=[])
+def test_should_run(mock_measurement, *args):
     cycle = {}
     should_run, *args = _should_run(cycle)
     assert not should_run
 
     mock_measurement.return_value = [10]
     should_run, *args = _should_run(cycle)
-    assert should_run
+    assert should_run is True
 
 
 @patch(f"{class_path}._new_emission", side_effect=fake_new_emission)
